==> foundation-2.6.1.tgz: package/SocialPinterest/SocialPinterest.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const SocialPinterest = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M50.001 10.999C28.464 10.999 11 28.461 11 50c0 15.97 9.603 29.688 23.345 35.72-.11-2.723-.021-5.994.679-8.953.75-3.168 5.018-21.252 5.018-21.252s-1.246-2.49-1.246-6.17c0-5.779 3.35-10.098 7.52-10.098 3.547 0 5.261 2.664 5.261 5.855 0 3.566-2.273 8.896-3.443 13.84-.978 4.139 2.075 7.512 6.156 7.512 7.389 0 12.365-9.49 12.365-20.736 0-8.545-5.756-14.943-16.227-14.943-11.831 0-19.201 8.822-19.201 18.676 0 3.4 1.002 5.795 2.572 7.648.721.853.821 1.196.56 2.176-.187.717-.617 2.444-.794 3.129-.259.988-1.059 1.34-1.953.976-5.449-2.225-7.987-8.192-7.987-14.9 0-11.08 9.343-24.363 27.873-24.363 14.891 0 24.691 10.775 24.691 22.344 0 15.297-8.506 26.727-21.044 26.727-4.209 0-8.17-2.277-9.527-4.861 0 0-2.264 8.984-2.743 10.722-.827 3.007-2.446 6.013-3.926 8.354a38.983 38.983 0 0011.053 1.6C71.538 89.001 89 71.538 89 50c0-21.539-17.462-39.001-38.999-39.001z"
  }));
});
SocialPinterest.displayName = 'SocialPinterest';
export const SocialPinterestDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/SocialPinterest/SocialPinterest.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialPinterest = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M50.001 10.999C28.464 10.999 11 28.461 11 50c0 15.97 9.603 29.688 23.345 35.72-.11-2.723-.021-5.994.679-8.953.75-3.168 5.018-21.252 5.018-21.252s-1.246-2.49-1.246-6.17c0-5.779 3.35-10.098 7.52-10.098 3.547 0 5.261 2.664 5.261 5.855 0 3.566-2.273 8.896-3.443 13.84-.978 4.139 2.075 7.512 6.156 7.512 7.389 0 12.365-9.49 12.365-20.736 0-8.545-5.756-14.943-16.227-14.943-11.831 0-19.201 8.822-19.201 18.676 0 3.4 1.002 5.795 2.572 7.648.721.853.821 1.196.56 2.176-.187.717-.617 2.444-.794 3.129-.259.988-1.059 1.34-1.953.976-5.449-2.225-7.987-8.192-7.987-14.9 0-11.08 9.343-24.363 27.873-24.363 14.891 0 24.691 10.775 24.691 22.344 0 15.297-8.506 26.727-21.044 26.727-4.209 0-8.17-2.277-9.527-4.861 0 0-2.264 8.984-2.743 10.722-.827 3.007-2.446 6.013-3.926 8.354a38.983 38.983 0 0011.053 1.6C71.538 89.001 89 71.538 89 50c0-21.539-17.462-39.001-38.999-39.001z"
  }));
});
SocialPinterest.displayName = 'SocialPinterest';
export var SocialPinterestDimensions = {
  height: 100,
  width: 100
};
